==> quick_resto_API-1.0.5.tar.gz: quick_resto_API-1.0.5/quick_resto_API/operations_with_objects/modules/order_discard_reason_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.order_discard_reason import OrderDiscardReason

class OrderDiscardReasonOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.orderdiscardreasons"

    def get_list_of_order_discard_reason(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(OrderDiscardReason(**object))

        return result

    def get_tree_of_order_discard_reason(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(OrderDiscardReason(**object))

        return result

    def get_order_discard_reason(self, objectId: int, objectRid: int = None) -> OrderDiscardReason:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return OrderDiscardReason(**json_response)

    def get_order_discard_reason_with_subobjects(self, objectId: int, objectRid: int = None) -> OrderDiscardReason:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return OrderDiscardReason(**json_response)

    def create_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def update_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def remove_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def recover_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

==> quick_resto_API-1.1.2.tar.gz: quick_resto_API-1.1.2/quick_resto_API/operations_with_objects/modules/order_discard_reason_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.order_discard_reason import OrderDiscardReason

class OrderDiscardReasonOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.orderdiscardreasons"

    def get_list_of_order_discard_reason(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[OrderDiscardReason]:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[OrderDiscardReason] = list()

        for object in json_response:
            result.append(OrderDiscardReason(**object))

        return result

    def get_tree_of_order_discard_reason(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[OrderDiscardReason]:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[OrderDiscardReason] = list()

        for object in json_response:
            result.append(OrderDiscardReason(**object))

        return result

    def get_order_discard_reason(self, objectId: int, objectRid: int = None) -> OrderDiscardReason:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return OrderDiscardReason(**json_response)

    def get_order_discard_reason_with_subobjects(self, objectId: int, objectRid: int = None) -> OrderDiscardReason:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return OrderDiscardReason(**json_response)

    def create_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def update_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def remove_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)

    def recover_order_discard_reason(self, object: OrderDiscardReason,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> OrderDiscardReason:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return OrderDiscardReason(**json_response)
